pub struct NewLines { /* private fields */ }Expand description
A datastructure that stores the location of newline characters of a string. It also offers some useful methods to determine the line-number of an offset-location.
Implementations
Sourceimpl NewLines
impl NewLines
pub fn build(str: &str) -> NewLines
Sourcepub fn get_line_nr(&self, offset: usize) -> usize
pub fn get_line_nr(&self, offset: usize) -> usize
returns the 0 based line-nr of the given offset-location
Sourcepub fn get_column(&self, line: usize, offset: usize) -> usize
pub fn get_column(&self, line: usize, offset: usize) -> usize
returns the 0 based column of the given offset-location
Sourcepub fn get_end_of_line(&self, line: usize) -> usize
pub fn get_end_of_line(&self, line: usize) -> usize
returns the 0 based column of end-of-line character for the given line