SourceLocation

Struct SourceLocation 

pub struct SourceLocation { /* private fields */ }

Implementations

Source

impl SourceLocation

pub fn into_internal(self) -> Self

pub fn undefined() -> SourceLocation

Constructs an undefined SourceRange with a 0..0 range and no filename

pub fn get_line(&self) -> usize

Gets the line representation for a source location If the location does not represent a line, the closest equivalent is returned That is 0 for None and the ID for id/inner spans

pub fn get_line_end(&self) -> usize

Gets the line representation for a source location If the location does not represent a line, the closest equivalent is returned That is 0 for None and the ID for id/inner spans

pub fn get_line_plus_one(&self) -> usize

Same as [get_line] but adds one to the line number if its of type CodeSpan::Range.

pub fn get_column(&self) -> usize

Gets the colmumn representation for a source location If the location does not represent a line, 0 is returned

pub fn get_column_end(&self) -> usize

Gets the colmumn representation for a source location If the location does not represent a line, 0 is returned

pub fn span(&self, other: &SourceLocation) -> SourceLocation

returns a new SourceRange that spans this and the other range. In other words this results in self.start .. other.end

pub fn to_range(&self) -> Option<Range<usize>>

converts this SourceRange into a Range

pub fn get_file_name(&self) -> Option<&'static str>

pub fn is_undefined(&self) -> bool

returns true if this SourceRange points to an undefined location. see SourceRange::undefined()

pub fn get_span(&self) -> &CodeSpan

pub fn replace_with(&mut self, new_location: SourceLocation)

pub fn internal() -> Self

creates a SymbolLocation with undefined source_range used for symbols that are created by the compiler on-the-fly.

pub fn internal_in_unit(unit: Option<&'static str>) -> Self

creates an internal SymbolLocation but specifies the CompilationUnit/File it was encountered in. This can be necessary when checking if dependencies are located within the same unit as the internally generated element

pub fn is_internal(&self) -> bool

pub fn is_builtin_internal(&self) -> bool

pub fn is_in_unit(&self, unit: impl AsRef<str>) -> bool